@@ -63,7 +63,7 @@ class ProfileReadContract(ProfileCreateContract):
     # Underwriting
     is_identified = serializers.BooleanField()
     is_verified = serializers.BooleanField()
-    is_signed = serializers.BooleanField()
+    sign_date = serializers.DateField(allow_null=True)
     credit_score = serializers.DecimalField(max_digits=3, decimal_places=2, allow_null=True)
     credit_score_created = serializers.DateTimeField(allow_null=True)
     # Address
@@ -91,7 +91,7 @@ class RussianProfileCreateContract(ProfileCreateContract):
     snils = serializers.CharField(max_length=64, allow_null=True, allow_blank=True)
 
 
-class RussianProfileReadContract(ProfileReadContract, ):
+class RussianProfileReadContract(ProfileReadContract):
     passport_serial = serializers.CharField(max_length=4)
     passport_number = serializers.CharField(max_length=6)
     passport_issue_name = serializers.CharField(max_length=256, allow_blank=True)
